==> foamlib-0.8.10.tar.gz: foamlib-0.8.10/tests/test_files/test_parsing/test_basic.py <==
import numpy as np
from foamlib import FoamFile
from foamlib._files._parsing import Parsed


def test_parse_value() -> None:
    assert Parsed(b"1")[()] == 1
    assert Parsed(b"1.0")[()] == 1.0
    assert Parsed(b"1.0e-3")[()] == 1.0e-3
    assert Parsed(b"yes")[()] is True
    assert Parsed(b"no")[()] is False
    assert Parsed(b"word")[()] == "word"
    assert Parsed(b"inference")[()] == "inference"
    assert Parsed(b"word word")[()] == ("word", "word")
    assert Parsed(b'"a string"')[()] == '"a string"'
    assert Parsed(b"uniform 1")[()] == 1
    assert Parsed(b"uniform 1.0")[()] == 1.0
    assert Parsed(b"uniform 1.0e-3")[()] == 1.0e-3
    assert Parsed(b"(1.0 2.0 3.0)")[()] == [1.0, 2.0, 3.0]
    field = Parsed(b"uniform (1 2 3)")[()]
    assert isinstance(field, np.ndarray)
    assert np.array_equal(field, [1, 2, 3])
    field = Parsed(b"nonuniform List<scalar> 2(1 2)")[()]
    assert isinstance(field, np.ndarray)
    assert np.array_equal(field, [1, 2])
    field = Parsed(b"nonuniform List<scalar> 2{1}")[()]
    assert isinstance(field, np.ndarray)
    assert np.array_equal(field, [1, 1])
    assert Parsed(b"3(1 2 3)")[()] == [1, 2, 3]
    assert Parsed(b"2((1 2 3) (4 5 6))")[()] == [
        [1, 2, 3],
        [4, 5, 6],
    ]
    assert Parsed(b"2{(1 2 3)}")[()] == [
        [1, 2, 3],
        [1, 2, 3],
    ]
    field = Parsed(b"nonuniform List<vector> 2((1 2 3) (4 5 6))")[()]
    assert isinstance(field, np.ndarray)
    assert np.array_equal(
        field,
        [
            [1, 2, 3],
            [4, 5, 6],
        ],
    )
    field = Parsed(b"nonuniform List<vector> 2{(1 2 3)}")[()]
    assert isinstance(field, np.ndarray)
    assert np.array_equal(
        field,
        [
            [1, 2, 3],
            [1, 2, 3],
        ],
    )
    field = Parsed(
        b"nonuniform List<scalar> 2(\x00\x00\x00\x00\x00\x00\xf0?\x00\x00\x00\x00\x00\x00\x00@)"
    )[()]
    assert isinstance(field, np.ndarray)
    assert np.array_equal(field, [1, 2])
    field = Parsed(
        b"nonuniform List<vector> 2(\x00\x00\x00\x00\x00\x00\xf0?\x00\x00\x00\x00\x00\x00\x00@\x00\x00\x00\x00\x00\x00\x08@\x00\x00\x00\x00\x00\x00\x10@\x00\x00\x00\x00\x00\x00\x14@\x00\x00\x00\x00\x00\x00\x18@)"
    )[()]
    assert isinstance(field, np.ndarray)
    assert np.array_equal(field, [[1, 2, 3], [4, 5, 6]])
    field = Parsed(b"nonuniform List<scalar> 2(\x00\x00\x80?\x00\x00\x00@)")[()]
    assert isinstance(field, np.ndarray)
    assert np.array_equal(field, [1, 2])
    assert Parsed(b"[1 1 -2 0 0 0 0]")[()] == FoamFile.DimensionSet(
        mass=1, length=1, time=-2
    )
    assert Parsed(b"g [1 1 -2 0 0 0 0] (0 0 -9.81)")[()] == FoamFile.Dimensioned(
        name="g",
        dimensions=FoamFile.DimensionSet(mass=1, length=1, time=-2),
        value=[0, 0, -9.81],
    )
    assert Parsed(b"[1 1 -2 0 0 0 0] 9.81")[()] == FoamFile.Dimensioned(
        dimensions=FoamFile.DimensionSet(mass=1, length=1, time=-2), value=9.81
    )
    assert Parsed(b"hex (0 1 2 3 4 5 6 7) (1 1 1) simpleGrading (1 1 1)")[()] == (
        "hex",
        [0, 1, 2, 3, 4, 5, 6, 7],
        [1, 1, 1],
        "simpleGrading",
        [1, 1, 1],
    )
    assert Parsed(b"(a b; c d;)")[()] == [("a", "b"), ("c", "d")]
    assert Parsed(b"(a {b c;} d {e g;})")[()] == [
        ("a", {"b": "c"}),
        ("d", {"e": "g"}),
    ]
    assert Parsed(b"(a (0 1 2); b {})")[()] == [("a", [0, 1, 2]), ("b", {})]
    assert Parsed(b"({a b; c d;} {e g;})")[()] == [{"a": "b", "c": "d"}, {"e": "g"}]
    assert Parsed(b"(water oil mercury air)")[()] == ["water", "oil", "mercury", "air"]
    assert Parsed(b"div(phi,U)")[()] == "div(phi,U)"
    assert Parsed(b"U.component(1)")[()] == "U.component(1)"
    assert Parsed(b"div(nuEff*dev(T(grad(U))))")[()] == "div(nuEff*dev(T(grad(U))))"
    assert Parsed(b"div((nuEff*dev(T(grad(U)))))")[()] == "div((nuEff*dev(T(grad(U)))))"
    assert Parsed(b"((air and water) { type constant; sigma 0.07; })")[()] == [
        (["air", "and", "water"], {"type": "constant", "sigma": 0.07})
    ]
    assert Parsed(b"[]")[()] == FoamFile.DimensionSet()
    assert Parsed(b"object f.1;")[("object",)] == "f.1"


def test_parse_directive() -> None:
    assert Parsed(b'#include "filename"')[("#include",)] == '"filename"'
    assert (
        Parsed(b"functions\n{\n#includeFunc funcName\nsubdict{}}")[
            ("functions", "#includeFunc")
        ]
        == "funcName"
    )

==> foamlib-0.9.0.tar.gz: foamlib-0.9.0/tests/test_files/test_parsing/test_basic.py <==
import numpy as np
from foamlib import FoamFile
from foamlib._files._parsing import Parsed


def test_parse_value() -> None:
    assert Parsed(b"1")[()] == 1
    assert Parsed(b"1.0")[()] == 1.0
    assert Parsed(b"1.0e-3")[()] == 1.0e-3
    assert Parsed(b"yes")[()] is True
    assert Parsed(b"no")[()] is False
    assert Parsed(b"word")[()] == "word"
    assert Parsed(b"inference")[()] == "inference"
    assert Parsed(b"word word")[()] == ("word", "word")
    assert Parsed(b'"a string"')[()] == '"a string"'
    assert Parsed(b"uniform 1")[()] == 1
    assert Parsed(b"uniform 1.0")[()] == 1.0
    assert Parsed(b"uniform 1.0e-3")[()] == 1.0e-3
    assert Parsed(b"(word word)")[()] == ["word", "word"]
    lst = Parsed(b"(1 2 3)")[()]
    assert isinstance(lst, np.ndarray)
    assert lst.dtype == np.int64
    assert np.array_equal(lst, [1, 2, 3])
    lst = Parsed(b"(1.0 2 3)")[()]
    assert isinstance(lst, np.ndarray)
    assert lst.dtype == np.float64
    assert np.array_equal(lst, [1.0, 2.0, 3.0])
    assert Parsed(b"()")[()] == []
    field = Parsed(b"uniform (1 2 3)")[()]
    assert isinstance(field, np.ndarray)
    assert np.array_equal(field, [1, 2, 3])
    field = Parsed(b"nonuniform List<scalar> 2(1 2)")[()]
    assert isinstance(field, np.ndarray)
    assert np.array_equal(field, [1, 2])
    field = Parsed(b"nonuniform List<scalar> 2{1}")[()]
    assert isinstance(field, np.ndarray)
    assert np.array_equal(field, [1, 1])
    field = Parsed(b"nonuniform List<symmTensor> 0()")[()]
    assert isinstance(field, np.ndarray)
    assert field.shape == (0, 6)
    field = Parsed(b"nonuniform List<tensor> ()")[()]
    assert isinstance(field, np.ndarray)
    assert field.shape == (0, 9)
    lst = Parsed(b"3(1 2 3)")[()]
    assert isinstance(lst, np.ndarray)
    assert np.array_equal(lst, [1, 2, 3])
    lst = Parsed(b"2((1 2 3) (4 5 6))")[()]
    assert isinstance(lst, np.ndarray)
    assert np.array_equal(
        lst,
        [
            [1, 2, 3],
            [4, 5, 6],
        ],
    )
    lst = Parsed(b"2{(1 2 3)}")[()]
    assert isinstance(lst, np.ndarray)
    assert np.array_equal(
        lst,
        [
            [1, 2, 3],
            [1, 2, 3],
        ],
    )
    assert Parsed(b"0()")[()] == []
    field = Parsed(b"nonuniform List<vector> 2((1 2 3) (4 5 6))")[()]
    assert isinstance(field, np.ndarray)
    assert np.array_equal(
        field,
        [
            [1, 2, 3],
            [4, 5, 6],
        ],
    )
    field = Parsed(b"nonuniform List<vector> 2{(1 2 3)}")[()]
    assert isinstance(field, np.ndarray)
    assert np.array_equal(
        field,
        [
            [1, 2, 3],
            [1, 2, 3],
        ],
    )
    field = Parsed(
        b"nonuniform List<scalar> 2(\x00\x00\x00\x00\x00\x00\xf0?\x00\x00\x00\x00\x00\x00\x00@)"
    )[()]
    assert isinstance(field, np.ndarray)
    assert np.array_equal(field, [1, 2])
    field = Parsed(
        b"nonuniform List<vector> 2(\x00\x00\x00\x00\x00\x00\xf0?\x00\x00\x00\x00\x00\x00\x00@\x00\x00\x00\x00\x00\x00\x08@\x00\x00\x00\x00\x00\x00\x10@\x00\x00\x00\x00\x00\x00\x14@\x00\x00\x00\x00\x00\x00\x18@)"
    )[()]
    assert isinstance(field, np.ndarray)
    assert np.array_equal(field, [[1, 2, 3], [4, 5, 6]])
    field = Parsed(b"nonuniform List<scalar> 2(\x00\x00\x80?\x00\x00\x00@)")[()]
    assert isinstance(field, np.ndarray)
    assert np.array_equal(field, [1, 2])
    assert Parsed(b"[1 1 -2 0 0 0 0]")[()] == FoamFile.DimensionSet(
        mass=1, length=1, time=-2
    )
    assert Parsed(b"g [1 1 -2 0 0 0 0] (0 0 -9.81)")[()] == FoamFile.Dimensioned(
        name="g",
        dimensions=FoamFile.DimensionSet(mass=1, length=1, time=-2),
        value=[0, 0, -9.81],
    )
    assert Parsed(b"[1 1 -2 0 0 0 0] 9.81")[()] == FoamFile.Dimensioned(
        dimensions=FoamFile.DimensionSet(mass=1, length=1, time=-2), value=9.81
    )
    tpl = Parsed(b"hex (0 1 2 3 4 5 6 7) (1 1 1) simpleGrading (1 1 1)")[()]
    assert isinstance(tpl, tuple)
    assert len(tpl) == 5
    assert tpl[0] == "hex"
    assert isinstance(tpl[1], np.ndarray)
    assert tpl[1].dtype == np.int64
    assert np.array_equal(tpl[1], [0, 1, 2, 3, 4, 5, 6, 7])
    assert isinstance(tpl[2], np.ndarray)
    assert tpl[2].dtype == np.int64
    assert np.array_equal(tpl[2], [1, 1, 1])
    assert tpl[3] == "simpleGrading"
    assert isinstance(tpl[4], np.ndarray)
    assert tpl[4].dtype == np.int64
    assert np.array_equal(tpl[4], [1, 1, 1])
    assert Parsed(b"(a b; c d;)")[()] == [("a", "b"), ("c", "d")]
    assert Parsed(b"(a {b c;} d {e g;})")[()] == [
        ("a", {"b": "c"}),
        ("d", {"e": "g"}),
    ]
    assert Parsed(b"(a (b c d); e {})")[()] == [("a", ["b", "c", "d"]), ("e", {})]
    assert Parsed(b"({a b; c d;} {e g;})")[()] == [{"a": "b", "c": "d"}, {"e": "g"}]
    assert Parsed(b"(water oil mercury air)")[()] == ["water", "oil", "mercury", "air"]
    assert Parsed(b"div(phi,U)")[()] == "div(phi,U)"
    assert Parsed(b"U.component(1)")[()] == "U.component(1)"
    assert Parsed(b"div(nuEff*dev(T(grad(U))))")[()] == "div(nuEff*dev(T(grad(U))))"
    assert Parsed(b"div((nuEff*dev(T(grad(U)))))")[()] == "div((nuEff*dev(T(grad(U)))))"
    assert Parsed(b"((air and water) { type constant; sigma 0.07; })")[()] == [
        (["air", "and", "water"], {"type": "constant", "sigma": 0.07})
    ]
    assert Parsed(b"[]")[()] == FoamFile.DimensionSet()
    assert Parsed(b"object f.1;")[("object",)] == "f.1"


def test_parse_directive() -> None:
    assert Parsed(b'#include "filename"')[("#include",)] == '"filename"'
    assert (
        Parsed(b"functions\n{\n#includeFunc funcName\nsubdict{}}")[
            ("functions", "#includeFunc")
        ]
        == "funcName"
    )
